@@ -7,6 +7,7 @@ pub enum EventType {
     ExecDone,
     Read,
     Write,
+    Miss,
 }
 
 #[derive(Debug)]
@@ -22,6 +23,7 @@ pub enum EventData<'a> {
     },
     Read,
     Write,
+    Miss,
 }
 
 impl EventData<'_> {
@@ -31,18 +33,20 @@ impl EventData<'_> {
             EventData::ExecDone { .. } => EventType::ExecDone,
             EventData::Read => EventType::Read,
             EventData::Write => EventType::Write,
+            EventData::Miss => EventType::Miss,
         }
     }
 }
 
 impl EventType {
-    pub const fn get_str(&self) -> &'static str {
+    pub const fn get_code(&self) -> i8 {
         use EventType::*;
         match self {
-            ExecDone => "ExecDone",
-            Exec => "Exec",
-            Read => "Read",
-            Write => "Write",
+            Read => 0,
+            Write => 1,
+            Miss => 2,
+            Exec => 3,
+            ExecDone => 4,
         }
     }
 }
@@ -52,4 +56,5 @@ pub struct Event<'a> {
     pub data: EventData<'a>,
     pub script_id: i64,
     pub time: NaiveDateTime,
+    pub humble: bool,
 }
